==> mysql-8.0.18.tar.gz: mysql-8.0.18/client/dump/standard_progress_watcher.h <==
/*
  Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef STANDARD_PROGRESS_WATCHER_INCLUDED
#define STANDARD_PROGRESS_WATCHER_INCLUDED

#include <functional>

#include "client/dump/abstract_progress_watcher.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class Standard_progress_watcher : public Abstract_progress_watcher {
 public:
  Standard_progress_watcher(
      std::function<bool(const Mysql::Tools::Base::Message_data &)>
          *message_handler,
      Simple_id_generator *object_id_generator);

  void process_progress_step(Abstract_progress_watcher::Progress_data &change);
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif

==> mysql-8.0.22.tar.gz: mysql-8.0.22/client/dump/standard_progress_watcher.h <==
/*
  Copyright (c) 2015, 2020, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef STANDARD_PROGRESS_WATCHER_INCLUDED
#define STANDARD_PROGRESS_WATCHER_INCLUDED

#include <functional>

#include "client/dump/abstract_progress_watcher.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class Standard_progress_watcher : public Abstract_progress_watcher {
 public:
  Standard_progress_watcher(
      std::function<bool(const Mysql::Tools::Base::Message_data &)>
          *message_handler,
      Simple_id_generator *object_id_generator);

  void process_progress_step(
      Abstract_progress_watcher::Progress_data &change) override;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif
